Class: Cline::McpSettings::McpServer

Inherits:
Schema
  • Object
show all
Defined in:
lib/cline/mcp_settings.rb

Overview

Settings associated to 1 MCP server

Instance Attribute Summary

Attributes inherited from Schema

#extra_attributes

Public API collapse

Methods inherited from Schema

#==, as_hash, cast, cline_snake_attributes, of_hash, #to_cline_json, #to_hash

Instance Method Details

#auto_approveArray<String>

Returns List of tools that are automatically approved for this server.

Returns:

  • (Array<String>)

    List of tools that are automatically approved for this server



12
# File 'lib/cline/mcp_settings.rb', line 12

attribute :auto_approve, Utils::Schema.collection(:string)

#disabledBoolean

Returns Flag indicating if this server is disabled.

Returns:

  • (Boolean)

    Flag indicating if this server is disabled



15
# File 'lib/cline/mcp_settings.rb', line 15

attribute :disabled, :boolean

#timeoutInteger

Returns Server timeout in seconds.

Returns:

  • (Integer)

    Server timeout in seconds



18
# File 'lib/cline/mcp_settings.rb', line 18

attribute :timeout, :integer

#typeString

Returns Server connection type (e.g. "sse", "stdio").

Returns:

  • (String)

    Server connection type (e.g. "sse", "stdio")



21
# File 'lib/cline/mcp_settings.rb', line 21

attribute :type, :string

#urlString

Returns Server URL for SSE connections.

Returns:

  • (String)

    Server URL for SSE connections



24
# File 'lib/cline/mcp_settings.rb', line 24

attribute :url, :string