Class: Cline::Providers

Inherits:
Schema
  • Object
show all
Defined in:
lib/cline/providers.rb

Overview

Providers configuration stored in settings/providers.json

Defined Under Namespace

Classes: ProviderEntry

Instance Attribute Summary

Attributes inherited from Schema

#extra_attributes

Public API collapse

Methods inherited from Schema

#==, as_hash, cast, cline_snake_attributes, of_hash, #to_cline_json, #to_hash

Instance Method Details

#last_used_providerString

Returns The last used provider identifier.

Returns:

  • (String)

    The last used provider identifier



54
# File 'lib/cline/providers.rb', line 54

attribute :last_used_provider, :string

#providersHash

Returns The map of provider entries keyed by provider name.

Returns:

  • (Hash)

    The map of provider entries keyed by provider name



57
# File 'lib/cline/providers.rb', line 57

attribute :providers, Utils::Schema.map(ProviderEntry)

#versionInteger

Returns The version of the providers configuration.

Returns:

  • (Integer)

    The version of the providers configuration



51
# File 'lib/cline/providers.rb', line 51

attribute :version, :integer