Class: Cline::Providers::ProviderEntry

Inherits:
Schema
  • Object
show all
Defined in:
lib/cline/providers.rb

Overview

A provider entry with settings, update timestamp and token source

Defined Under Namespace

Classes: ProviderSettings

Instance Attribute Summary

Attributes inherited from Schema

#extra_attributes

Public API collapse

Methods inherited from Schema

#==, as_hash, cast, cline_snake_attributes, of_hash, #to_cline_json, #to_hash

Instance Method Details

#settingsProviderSettings

Returns The provider settings.

Returns:



41
# File 'lib/cline/providers.rb', line 41

attribute :settings, ProviderSettings

#token_sourceString

Returns The token source (e.g. "manual").

Returns:

  • (String)

    The token source (e.g. "manual")



47
# File 'lib/cline/providers.rb', line 47

attribute :token_source, :string

#updated_atString

Returns The timestamp when this provider was last updated.

Returns:

  • (String)

    The timestamp when this provider was last updated



44
# File 'lib/cline/providers.rb', line 44

attribute :updated_at, :string