Class: Cline::McpSettings::McpServer
- Defined in:
- lib/cline/mcp_settings.rb
Overview
Settings associated to 1 MCP server
Instance Attribute Summary
Attributes inherited from Schema
Public API collapse
-
#auto_approve ⇒ Array<String>
List of tools that are automatically approved for this server.
-
#disabled ⇒ Boolean
Flag indicating if this server is disabled.
-
#timeout ⇒ Integer
Server timeout in seconds.
-
#type ⇒ String
Server connection type (e.g. "sse", "stdio").
-
#url ⇒ String
Server URL for SSE connections.
Methods inherited from Schema
#==, as_hash, cast, cline_snake_attributes, of_hash, #to_cline_json, #to_hash
Instance Method Details
#auto_approve ⇒ Array<String>
Returns List of tools that are automatically approved for this server.
12 |
# File 'lib/cline/mcp_settings.rb', line 12 attribute :auto_approve, Utils::Schema.collection(:string) |
#disabled ⇒ Boolean
Returns Flag indicating if this server is disabled.
15 |
# File 'lib/cline/mcp_settings.rb', line 15 attribute :disabled, :boolean |
#timeout ⇒ Integer
Returns Server timeout in seconds.
18 |
# File 'lib/cline/mcp_settings.rb', line 18 attribute :timeout, :integer |
#type ⇒ String
Returns Server connection type (e.g. "sse", "stdio").
21 |
# File 'lib/cline/mcp_settings.rb', line 21 attribute :type, :string |
#url ⇒ String
Returns Server URL for SSE connections.
24 |
# File 'lib/cline/mcp_settings.rb', line 24 attribute :url, :string |