Class: Cline::Providers
- Defined in:
- lib/cline/providers.rb
Overview
Providers configuration stored in settings/providers.json
Defined Under Namespace
Classes: ProviderEntry
Instance Attribute Summary
Attributes inherited from Schema
Public API collapse
-
#last_used_provider ⇒ String
The last used provider identifier.
-
#providers ⇒ Hash
The map of provider entries keyed by provider name.
-
#version ⇒ Integer
The version of the providers configuration.
Methods inherited from Schema
#==, as_hash, cast, cline_snake_attributes, of_hash, #to_cline_json, #to_hash
Instance Method Details
#last_used_provider ⇒ String
Returns The last used provider identifier.
54 |
# File 'lib/cline/providers.rb', line 54 attribute :last_used_provider, :string |
#providers ⇒ Hash
Returns The map of provider entries keyed by provider name.
57 |
# File 'lib/cline/providers.rb', line 57 attribute :providers, Utils::Schema.map(ProviderEntry) |
#version ⇒ Integer
Returns The version of the providers configuration.
51 |
# File 'lib/cline/providers.rb', line 51 attribute :version, :integer |