Class: Cline::Providers::ProviderEntry
- Defined in:
- lib/cline/providers.rb
Overview
A provider entry with settings, update timestamp and token source
Defined Under Namespace
Classes: ProviderSettings
Instance Attribute Summary
Attributes inherited from Schema
Public API collapse
-
#settings ⇒ ProviderSettings
The provider settings.
-
#token_source ⇒ String
The token source (e.g. "manual").
-
#updated_at ⇒ String
The timestamp when this provider was last updated.
Methods inherited from Schema
#==, as_hash, cast, cline_snake_attributes, of_hash, #to_cline_json, #to_hash
Instance Method Details
#settings ⇒ ProviderSettings
Returns The provider settings.
41 |
# File 'lib/cline/providers.rb', line 41 attribute :settings, ProviderSettings |
#token_source ⇒ String
Returns The token source (e.g. "manual").
47 |
# File 'lib/cline/providers.rb', line 47 attribute :token_source, :string |
#updated_at ⇒ String
Returns The timestamp when this provider was last updated.
44 |
# File 'lib/cline/providers.rb', line 44 attribute :updated_at, :string |